@@ -158,7 +158,7 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
             module_list.append(env)
         
     def generate_module_preamble(self, env, cimported_modules, code):
-        code.putln('/* Generated by Pyrex %s on %s */' % (
+        code.putln('/* Generated by Cython %s on %s */' % (
             Version.version, time.asctime()))
         code.putln('')
         code.putln('#define PY_SSIZE_T_CLEAN')
