@@ -5,7 +5,7 @@
 import os, re
 from string import join, replace
 from types import ListType, TupleType
-from Scanning import PyrexScanner
+from Scanning import PyrexScanner, function_contexts
 import Nodes
 import ExprNodes
 from ModuleNode import ModuleNode
@@ -1455,10 +1455,10 @@ def p_c_declarator(s, empty = 0, is_type = 0, cmethod_flag = 0 , assignable = 0)
                 args = p_c_arg_list(s, in_pyfunc = 0, cmethod_flag = cmethod_flag)
                 ellipsis = p_optional_ellipsis(s)
                 s.expect(')')
-                exc_val, exc_check = p_exception_value_clause(s)
+                options = p_c_func_options(s)
                 result = Nodes.CFuncDeclaratorNode(pos, 
                     base = result, args = args, has_varargs = ellipsis,
-                    exception_value = exc_val, exception_check = exc_check)
+                    **options)
             cmethod_flag = 0
     return result
 
@@ -1477,6 +1477,37 @@ def p_exception_value_clause(s):
             exc_val = p_simple_expr(s) #p_exception_value(s)
     return exc_val, exc_check
 
+def p_c_with(s):
+    if s.sy == 'with':
+        s.next()
+        return p_ident_list(s)
+    return ()
+
+def p_c_func_options(s):
+    exc_val = None
+    exc_check = 0
+    contexts = []
+
+    if s.sy == 'except':
+        exc_val, exc_check = p_exception_value_clause(s)
+        contexts = p_c_with(s)
+    elif s.sy == 'with':
+        contexts = p_c_with(s)
+        exc_val, exc_check = p_exception_value_clause(s)
+
+    for context in contexts:
+        if context not in function_contexts:
+            s.error("Unknown context: " + context)
+            return None
+
+    ret = {
+        'exception_value': exc_val,
+        'exception_check': exc_check,
+        'with_gil': 'GIL' in contexts,
+        }
+
+    return ret
+
 #def p_exception_value(s):
 #	sign = ""
 #	if s.sy == "-":
