@@ -260,6 +260,8 @@ class CType(PyrexType):
     
     to_py_function = None
     from_py_function = None
+    exception_value = None
+    exception_check = 1
 
 
 #class CSimpleType(CType):
@@ -332,6 +334,7 @@ class CIntType(CNumericType):
     typedef_flag = 0
     to_py_function = "PyInt_FromLong"
     from_py_function = "PyInt_AsLong"
+    exception_value = -1
 
     def __init__(self, rank, signed, pymemberdef_typecode = None, is_returncode = 0):
         CNumericType.__init__(self, rank, signed, pymemberdef_typecode)
@@ -347,33 +350,35 @@ class CBIntType(CIntType):
     #       and no error checking should be needed (just an incref). 
     to_py_function = "__Pyx_PyBool_FromLong"
     from_py_function = "__Pyx_PyObject_IsTrue"
+    exception_check = 0
     
 
 class CPySSizeTType(CIntType):
 
     to_py_function = "PyInt_FromSsize_t"
     from_py_function = "__pyx_PyIndex_AsSsize_t"
-
+    exception_value = None
 
 class CUIntType(CIntType):
 
     to_py_function = "PyLong_FromUnsignedLong"
     from_py_function = "PyInt_AsUnsignedLongMask"
+    exception_value = None
 
 
-class CULongType(CIntType):
+class CULongType(CUIntType):
 
     to_py_function = "PyLong_FromUnsignedLong"
     from_py_function = "PyInt_AsUnsignedLongMask"
 
 
-class CLongLongType(CIntType):
+class CLongLongType(CUIntType):
 
     to_py_function = "PyLong_FromLongLong"
     from_py_function = "PyInt_AsUnsignedLongLongMask"
 
 
-class CULongLongType(CIntType):
+class CULongLongType(CUIntType):
 
     to_py_function = "PyLong_FromUnsignedLongLong"
     from_py_function = "PyInt_AsUnsignedLongLongMask"
@@ -488,16 +493,18 @@ class CFuncType(CType):
     #  has_varargs      boolean
     #  exception_value  string
     #  exception_check  boolean  True if PyErr_Occurred check needed
+    #  with_gil         boolean  True if GIL should be grabbed/released
     
     is_cfunction = 1
     
     def __init__(self, return_type, args, has_varargs,
-            exception_value = None, exception_check = 0):
+            exception_value = None, exception_check = 0, with_gil = False):
         self.return_type = return_type
         self.args = args
         self.has_varargs = has_varargs
         self.exception_value = exception_value
         self.exception_check = exception_check
+        self.with_gil = with_gil
     
     def __repr__(self):
         arg_reprs = map(repr, self.args)
@@ -580,6 +587,7 @@ class CFuncType(CType):
         if not arg_decl_code and not pyrex:
             arg_decl_code = "void"
         exc_clause = ""
+        with_gil_clause = ""
         if pyrex or for_display:
             if self.exception_value and self.exception_check:
                 exc_clause = " except? %s" % self.exception_value
@@ -587,8 +595,11 @@ class CFuncType(CType):
                 exc_clause = " except %s" % self.exception_value
             elif self.exception_check:
                 exc_clause = " except *"
+            if self.with_gil:
+                with_gil_clause = " with GIL"
         return self.return_type.declaration_code(
-            "(%s(%s)%s)" % (entity_code, arg_decl_code, exc_clause),
+            "(%s(%s)%s%s)" % (entity_code, arg_decl_code,
+                              exc_clause, with_gil_clause),
             for_display, dll_linkage, pyrex)
 
 
@@ -703,6 +714,7 @@ class CStringType:
     
     to_py_function = "PyString_FromString"
     from_py_function = "PyString_AsString"
+    exception_value = "NULL"
 
     def literal_code(self, value):
         return '"%s"' % value
