@@ -9,6 +9,9 @@ setup(
     Extension("spam",         ["spam.pyx"]),
 #    Extension("numeric_demo", ["numeric_demo.pyx"]),
     Extension("test", ["test.pyx"]),
+    Extension("func_pointers", ["func_pointers.pyx"]),
+    Extension("inplace", ["inplace.pyx"]),
+    Extension("withGIL", ["withGIL.pyx"]),
     ],
   cmdclass = {'build_ext': build_ext},
 #  include_dirs = "/System/Library/Frameworks/Python.framework/Versions/2.3/include/python2.3/"
